#
# spec file for package kanshi
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           kanshi
Version:        1.7.0
Release:        1.3
Summary:        Dynamic display configuration
License:        MIT
Group:          System/GUI/Other
URL:            https://git.sr.ht/~emersion/kanshi
Source0:        https://git.sr.ht/~emersion/kanshi/refs/download/v%{version}/%{name}-%{version}.tar.gz
Source1:        https://git.sr.ht/~emersion/kanshi/refs/download/v%{version}/%{name}-%{version}.tar.gz.sig
# https://emersion.fr/.well-known/openpgpkey/hu/dj3498u4hyyarh35rkjfnghbjxug6b19
Source2:        %{name}.keyring
Patch1:         wayland-include-dirs.patch
BuildRequires:  cmake
BuildRequires:  meson
BuildRequires:  ninja
BuildRequires:  scdoc
BuildRequires:  pkgconfig(libvarlink)
BuildRequires:  pkgconfig(scfg)
BuildRequires:  pkgconfig(wayland-client)

%description
kanshi allows you to define output profiles that are automatically enabled
and disabled on hotplug.

%prep
%autosetup -p1

%build
%meson \
  -Dipc=enabled
%meson_build

%install
%meson_install

%check
%meson_test

%files
%{_bindir}/kanshi
%{_bindir}/kanshictl
%{_mandir}/man?/%{name}*

%changelog
* Thu Jun 13 2024 Joshua Smith <smolsheep@opensuse.org>
- Update to v1.7.0:
  * parser: implements global output defaults
  * parser: disallow duplicate outputs
  * parser: implements output alias directive
  * config: fix fields bitmask in apply_output_defaults()
  * config: disallow using wildcard outputs in global scope
  * build: add fallback for libscfg
  * Fix cleanup of uninitialized values in error codepath
  * doc: fully document output criteria
  * Rename parser.c to config.c
  * Attempt switching all profiles with the same name
* Thu Jun  6 2024 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Add kanshictl. New command when IPC is enabled
* Thu May 30 2024 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Add ./wayland-include-dirs.patch
* Sun May 19 2024 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Enable IPC support with libvarlink
* Mon Apr 22 2024 Joshua Smith <smolsheep@opensuse.org>
- Add keyring and signature for package.
- Enable tests
- Update to v1.6.0:
  * Fix memory leaks on exit
  * Switch to scfg
  * readme: add ircs:// link for IRC channel
  * Add support for output blocks
  * doc: document output blocks
  * Include line numbers in error messages
  * Define _POSIX_C_SOURCE globally
* Mon Feb 26 2024 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to v1.5.1:
  * Forget current profile on match_and_apply failure
* Wed Jan 17 2024 Andrea Manzini <andrea.manzini@suse.com>
- Update to v.1.5.0:
  * Bind to output manager v3 if v4 isn't supported
  * Wait for output configuration events when handling IPC calls
  * Fix missing IPC reply on config reload error
  * Add support for custom modes
    Implements: https://todo.sr.ht/~emersion/kanshi/80
* Fri Jun 30 2023 llyyr <llyyr.public@gmail.com>
- Update to v.1.4.0:
  * Add support for adaptive sync
  * Add kanshictl switch
  * Keep current profile if it still matches
  * Add --listen-fd
  * manpage improvements
* Thu Mar 16 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to v1.3.1:
  * Pick lowest delta when fuzzy matching refreshes
  * Fall back to "Unknown" when make/model/serial is unset
* Tue Aug 30 2022 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to v1.3.0:
  * This release adds an IPC interface with a kanshictl utility,
    improves make-model-serial matching, and fixes a handful of bugs.
    libvarlink is a new optional dependency.
  * Support output-management version 3 release requests
  * Improve the make-model-serial matching of outputs
  * Upgrade wlr-output-management-unstable-v1.xml to version 2
* Sun Jun 26 2022 Tomasz Hołubowicz <alternateved@pm.me>
- Update to v1.2.0
  * parser: print errno when failing to open the config file
  * parser: explicitly initialize key (kanshi_output_field) to 0
  * [man 5] Add blockquotes to ensure line break
  * Properly reap children to avoid zombies
  * Add missing header after 5a30abdf0b3b
  * Accept user-specified config path
  * Add 'include' directive to read additional configs
  * Add the 'profile' directive in kanshi(5) examples
  * readme: move to Libera Chat
  * readme: switch to new profile syntax
  * build: bump version to 1.2.0
  * parser: use abort() instead of assert(0)
* Fri Apr 17 2020 Denis Kondratenko <denis.kondratenko@suse.com>
- Update to v1.1.0
  * Add support for comments in configuration file
  * Allow names to distinguish configuration
  * Add `exec` to execute commands when a configuration is matched
  * Be tolerant to matching refresh rates that are a few points off.
  * Select highest refresh rate for selected mode when none is specified.
  * Fix typo in man page
  * Use correct formatting for variable in man page
  * Specify correct version in meson.build
  * Fix parser_next_token return value
  * Require profiles with a name to have a profile directive
* Thu Sep  5 2019 Michael Aquilina <michaelaquilina@gmail.com>
- First kanshi release
